package repos

import (
	"context"
	"gralias/models"
)

type PlayersRepo interface {
	PlayerGetByName(username string) (*models.Player, error)
	PlayerAdd(player *models.Player) error
	PlayerUpdate(player *models.Player) error
	PlayerDelete(roomID, username string) error
	PlayerSetRoomID(username, roomID string) error
	PlayerExitRoom(username string) error
}

func (p *RepoProvider) PlayerGetByName(username string) (*models.Player, error) {
	var player models.Player
	err := p.DB.GetContext(context.Background(), &player, "SELECT id, room_id, username, team, role, is_bot FROM players WHERE username = ?", username)
	if err != nil {
		return nil, err
	}
	return &player, nil
}

func (p *RepoProvider) PlayerAdd(player *models.Player) error {
	_, err := p.DB.ExecContext(context.Background(), "INSERT INTO players (room_id, username, team, role, is_bot) VALUES (?, ?, ?, ?, ?)",
		player.RoomID, player.Username, player.Team, player.Role, player.IsBot)
	return err
}

func (p *RepoProvider) PlayerUpdate(player *models.Player) error {
	_, err := p.DB.ExecContext(context.Background(), "UPDATE players SET room_id = ?, username = ?, team = ?, role = ?, is_bot = ? WHERE id = ?",
		player.RoomID, player.Username, player.Team, player.Role, player.IsBot, player.ID)
	return err
}

func (p *RepoProvider) PlayerDelete(roomID, username string) error {
	_, err := p.DB.ExecContext(context.Background(), "DELETE FROM players WHERE room_id = ? AND username = ?", roomID, username)
	return err
}

func (p *RepoProvider) PlayerSetRoomID(username, roomID string) error {
	_, err := p.DB.ExecContext(context.Background(), "UPDATE players SET room_id = ? WHERE username = ?", roomID, username)
	return err
}

func (p *RepoProvider) PlayerExitRoom(username string) error {
	_, err := p.DB.ExecContext(context.Background(), "UPDATE players SET room_id = null WHERE username = ?", username)
	return err
}
